@@ -96,8 +96,8 @@ class TaskwarriorWrapper(object):
 
         self._notify_listeners('data changed')
 
-    def delete(self, ids):
-        self._internal_run([str(i) for i in ids] + ['del'])
+    def delete(self, ids, comment):
+        self._internal_run([str(i) for i in ids] + ['del', comment])
 
         self._notify_listeners('data changed')
 
@@ -114,5 +114,11 @@ class TaskwarriorWrapper(object):
     def reports(self):
         self._internal_run(['reports'])
 
+    def projects(self):
+        self._internal_run(['projects'])
+
+    def tags(self):
+        self._internal_run(['tags'])
+
     def invalidate_data(self):
         self._notify_listeners('data changed')
